@@ -19,9 +19,16 @@
 
 #include "task-title.h"
 
-#include <libmatewnck/libmatewnck.h>
+#define WNCK_I_KNOW_THIS_IS_UNSTABLE
+#include <libwnck/libwnck.h>
 #include <mate-panel-applet.h>
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#include <math.h>
+#define MATE_DESKTOP_USE_UNSTABLE_API
+#include <libmate-desktop/mate-desktop-utils.h>
+#endif
+
 #include "task-list.h"
 
 G_DEFINE_TYPE (TaskTitle, task_title, GTK_TYPE_EVENT_BOX);
@@ -35,8 +42,8 @@ G_DEFINE_TYPE (TaskTitle, task_title, GTK_TYPE_EVENT_BOX);
 
 struct _TaskTitlePrivate
 {
-  MatewnckScreen *screen;
-  MatewnckWindow *window;
+  WnckScreen *screen;
+  WnckWindow *window;
   GtkWidget *align;
   GtkWidget *box;
   GtkWidget *label;
@@ -56,7 +63,7 @@ on_close_clicked (GtkButton *button,
                   TaskTitle *title)
 {
   TaskTitlePrivate *priv;
-  MatewnckWindow *window;
+  WnckWindow *window;
 
   g_return_val_if_fail (TASK_IS_TITLE (title), FALSE);
   priv = title->priv;
@@ -64,19 +71,23 @@ on_close_clicked (GtkButton *button,
   if (event->button != 1 || !priv->mouse_in_close_button)
     return FALSE;
 
-  window = matewnck_screen_get_active_window (priv->screen);
+  window = wnck_screen_get_active_window (priv->screen);
 
-  if (!MATEWNCK_IS_WINDOW (window)
-        || matewnck_window_get_window_type (window) == MATEWNCK_WINDOW_DESKTOP)
+  if (!WNCK_IS_WINDOW (window)
+        || wnck_window_get_window_type (window) == WNCK_WINDOW_DESKTOP)
   {
+#if GTK_CHECK_VERSION (3, 0, 0)
+    mate_gdk_spawn_command_line_on_screen (gdk_screen_get_default (),
+#else
     gdk_spawn_command_line_on_screen (gdk_screen_get_default (),
+#endif
                                       LOGOUT, NULL);
   }
   else
   {
     if (priv->window == window)
       disconnect_window (title);
-    matewnck_window_close (window, GDK_CURRENT_TIME);
+    wnck_window_close (window, GDK_CURRENT_TIME);
   }
   gtk_widget_queue_draw (GTK_WIDGET (title));
 
@@ -110,8 +121,13 @@ on_leave_notify (GtkWidget *widget,
 }
 
 static gboolean
+#if GTK_CHECK_VERSION (3, 0, 0)
+on_button_draw (GtkWidget *widget, 
+                cairo_t *cr,
+#else
 on_button_expose (GtkWidget *widget, 
                   GdkEventExpose *event,
+#endif
                   TaskTitle *title)
 {
   g_return_val_if_fail (TASK_IS_TITLE (title), FALSE);
@@ -122,48 +138,70 @@ on_button_expose (GtkWidget *widget,
   if (priv->mouse_in_close_button)
   {
     GtkStyle *style = gtk_widget_get_style (widget);
-    gtk_paint_box (style, 
+#if GTK_CHECK_VERSION (3, 0, 0)
+    GdkRectangle area;
+    gdouble x1, y1, x2, y2;
+    cairo_clip_extents (cr, &x1, &y1, &x2, &y2);
+    area.x = floor (x1);
+    area.y = floor (y1);
+    area.width = ceil (x2) - area.x;
+    area.height = ceil (y2) - area.y;
+#endif
+    gtk_paint_box (style,
+#if GTK_CHECK_VERSION (3, 0, 0)
+                   cr,
+#else
                    event->window,
+#endif
                    GTK_STATE_PRELIGHT,
                    GTK_SHADOW_NONE,
+#if !GTK_CHECK_VERSION (3, 0, 0)
+                   NULL,
+#endif
                    NULL,
                    NULL,
-                   NULL,
+#if GTK_CHECK_VERSION (3, 0, 0)
+                   area.x,
+                   area.y + 2,
+                   area.width,
+                   area.height - 4);
+#else
                    event->area.x,
                    event->area.y + 2,
                    event->area.width,
-                   event->area.height - 4); 
+                   event->area.height - 4);
+#endif
   }
   return FALSE;
 }
 
 static void
-on_name_changed (MatewnckWindow *window, TaskTitle *title)
+on_name_changed (WnckWindow *window, TaskTitle *title)
 {
   TaskTitlePrivate *priv;
 
   g_return_if_fail (TASK_IS_TITLE (title));
-  g_return_if_fail (MATEWNCK_IS_WINDOW (window));
+  g_return_if_fail (WNCK_IS_WINDOW (window));
 
   priv = title->priv;
   if (priv->window != window)
     return;
 
   gtk_label_set_text (GTK_LABEL (title->priv->label),
-                      matewnck_window_get_name (window));
+                      wnck_window_get_name (window));
   gtk_widget_set_tooltip_text (GTK_WIDGET (title),
-                               matewnck_window_get_name (window));
+                               wnck_window_get_name (window));
   gtk_widget_queue_draw (GTK_WIDGET (title));
 }
 
 
 static void
-on_icon_changed (MatewnckWindow *window, TaskTitle *title)
+on_icon_changed (WnckWindow *window, TaskTitle *title)
 {
   TaskTitlePrivate *priv;
 
   g_return_if_fail (TASK_IS_TITLE (title));
-  g_return_if_fail (MATEWNCK_IS_WINDOW (window));
+  g_return_if_fail (WNCK_IS_WINDOW (window));
 
   priv = title->priv;
   if (priv->window != window)
@@ -173,21 +211,21 @@ on_icon_changed (MatewnckWindow *window, TaskTitle *title)
 }
 
 static void
-on_state_changed (MatewnckWindow *window, 
-                  MatewnckWindowState changed_mask,
-                  MatewnckWindowState new_state,
+on_state_changed (WnckWindow *window,
+                  WnckWindowState changed_mask,
+                  WnckWindowState new_state,
                   TaskTitle *title)
 {
   TaskTitlePrivate *priv;
 
   g_return_if_fail (TASK_IS_TITLE (title));
-  g_return_if_fail (MATEWNCK_IS_WINDOW (window));
+  g_return_if_fail (WNCK_IS_WINDOW (window));
 
   priv = title->priv;
   if (priv->window != window)
     return;
 
-  if (matewnck_window_is_maximized (window))
+  if (wnck_window_is_maximized (window))
   {
     gtk_widget_set_state (GTK_WIDGET (title), GTK_STATE_ACTIVE);
     gtk_widget_show (priv->box);
@@ -212,35 +250,35 @@ disconnect_window (TaskTitle *title)
 }
 
 static void
-on_active_window_changed (MatewnckScreen *screen, 
-                          MatewnckWindow *old_window,
+on_active_window_changed (WnckScreen *screen,
+                          WnckWindow *old_window,
                           TaskTitle   *title)
 {
   TaskTitlePrivate *priv;
-  MatewnckWindow *act_window;
-  MatewnckWindowType type = MATEWNCK_WINDOW_NORMAL;
+  WnckWindow *act_window;
+  WnckWindowType type = WNCK_WINDOW_NORMAL;
   
   g_return_if_fail (TASK_IS_TITLE (title));
   priv = title->priv;
 
-  act_window = matewnck_screen_get_active_window (screen);
+  act_window = wnck_screen_get_active_window (screen);
   if (act_window)
-    type = matewnck_window_get_window_type (act_window);
+    type = wnck_window_get_window_type (act_window);
 
-  if (MATEWNCK_IS_WINDOW (act_window) 
-      && matewnck_window_is_skip_tasklist (act_window)
-      && type != MATEWNCK_WINDOW_DESKTOP)
+  if (WNCK_IS_WINDOW (act_window)
+      && wnck_window_is_skip_tasklist (act_window)
+      && type != WNCK_WINDOW_DESKTOP)
     return;
 
-  if (type == MATEWNCK_WINDOW_DOCK
-      || type == MATEWNCK_WINDOW_SPLASHSCREEN
-      || type == MATEWNCK_WINDOW_MENU)
+  if (type == WNCK_WINDOW_DOCK
+      || type == WNCK_WINDOW_SPLASHSCREEN
+      || type == WNCK_WINDOW_MENU)
     return;
  
   disconnect_window (title);
 
-  if (!MATEWNCK_IS_WINDOW (act_window) 
-        || matewnck_window_get_window_type (act_window) == MATEWNCK_WINDOW_DESKTOP)
+  if (!WNCK_IS_WINDOW (act_window)
+        || wnck_window_get_window_type (act_window) == WNCK_WINDOW_DESKTOP)
   { 
     if (priv->show_home_title)
     {
@@ -264,12 +302,12 @@ on_active_window_changed (MatewnckScreen *screen,
   else
   {
     gtk_label_set_text (GTK_LABEL (priv->label), 
-                        matewnck_window_get_name (act_window));
+                        wnck_window_get_name (act_window));
     gtk_image_set_from_stock (GTK_IMAGE (priv->button_image), 
                               GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
 
     gtk_widget_set_tooltip_text (GTK_WIDGET (title),
-                                 matewnck_window_get_name (act_window));      
+                                 wnck_window_get_name (act_window));
     gtk_widget_set_tooltip_text (priv->button, _("Close window"));
 
     g_signal_connect (act_window, "name-changed",
@@ -282,14 +320,14 @@ on_active_window_changed (MatewnckScreen *screen,
     priv->window = act_window;
   }
 
-  if (MATEWNCK_IS_WINDOW (act_window)
-      && !matewnck_window_is_maximized (act_window) 
-      && (priv->show_home_title ? type != MATEWNCK_WINDOW_DESKTOP : 1))
+  if (WNCK_IS_WINDOW (act_window)
+      && !wnck_window_is_maximized (act_window)
+      && (priv->show_home_title ? type != WNCK_WINDOW_DESKTOP : 1))
   {
     gtk_widget_set_state (GTK_WIDGET (title), GTK_STATE_NORMAL);
     gtk_widget_hide (priv->box);
   }
-  else if (!MATEWNCK_IS_WINDOW (act_window))
+  else if (!WNCK_IS_WINDOW (act_window))
   {
     if (task_list_get_desktop_visible (TASK_LIST (task_list_get_default ()))
         && priv->show_home_title)
@@ -322,21 +360,21 @@ static gboolean
 on_button_release (GtkWidget *title, GdkEventButton *event)
 {
   TaskTitlePrivate *priv;
-  MatewnckWindow *window;
+  WnckWindow *window;
   GtkWidget *menu;
 
   g_return_val_if_fail (TASK_IS_TITLE (title), FALSE);
   priv = TASK_TITLE_GET_PRIVATE (title);
 
-  window = matewnck_screen_get_active_window (priv->screen);
+  window = wnck_screen_get_active_window (priv->screen);
 
-  g_return_val_if_fail (MATEWNCK_IS_WINDOW (window), FALSE);
+  g_return_val_if_fail (WNCK_IS_WINDOW (window), FALSE);
 
   if (event->button == 3)
   {
-    if (matewnck_window_get_window_type (window) != MATEWNCK_WINDOW_DESKTOP)
+    if (wnck_window_get_window_type (window) != WNCK_WINDOW_DESKTOP)
     {
-      menu = matewnck_action_menu_new (window);
+      menu = wnck_action_menu_new (window);
       gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 
                       event->button, event->time);
       return TRUE;
@@ -344,9 +382,9 @@ on_button_release (GtkWidget *title, GdkEventButton *event)
   }
   else if (event->button == 1)
   {
-    if (event->type == GDK_2BUTTON_PRESS && matewnck_window_is_maximized (window))
+    if (event->type == GDK_2BUTTON_PRESS && wnck_window_is_maximized (window))
     {
-      matewnck_window_unmaximize (window);
+      wnck_window_unmaximize (window);
     }
   }
   
@@ -355,20 +393,46 @@ on_button_release (GtkWidget *title, GdkEventButton *event)
 
 
 static gboolean
+#if GTK_CHECK_VERSION (3, 0, 0)
+on_draw (GtkWidget *eb, cairo_t *cr)
+#else
 on_expose (GtkWidget *eb, GdkEventExpose *event)
+#endif
 {
-  
-  if (eb->state == GTK_STATE_ACTIVE)
-    gtk_paint_box (eb->style, eb->window,
-                 eb->state, GTK_SHADOW_NONE,
-                 NULL, eb, "button",
-                 eb->allocation.x, eb->allocation.y, 
-                 eb->allocation.width, eb->allocation.height);
+  GtkAllocation *allocation;
+  GtkStyle *style;
+  GtkStateType state;
+
+  gtk_widget_get_allocation (eb, allocation);
+  style = gtk_widget_get_style (eb);
+  state = gtk_widget_get_state (eb);
+
+  if (state == GTK_STATE_ACTIVE)
+    gtk_paint_box (style,
+#if GTK_CHECK_VERSION (3, 0, 0)
+                 cr,
+#else
+                 eb->window,
+#endif
+                 state, GTK_SHADOW_NONE,
+#if !GTK_CHECK_VERSION (3, 0, 0)
+                 NULL,
+#endif
+                 eb, "button",
+                 allocation->x, allocation->y, 
+                 allocation->width, allocation->height);
   
   
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtk_container_propagate_draw (GTK_CONTAINER (eb),
+                                gtk_bin_get_child (GTK_BIN (eb)),
+                                cr);
+
+#else
   gtk_container_propagate_expose (GTK_CONTAINER (eb), 
                                   gtk_bin_get_child (GTK_BIN (eb)),
                                   event);
+#endif
   return TRUE;
 }
 
@@ -393,7 +457,11 @@ task_title_class_init (TaskTitleClass *klass)
   GtkWidgetClass      *wid_class = GTK_WIDGET_CLASS (klass);
 
   obj_class->finalize = task_title_finalize;
+#if GTK_CHECK_VERSION (3, 0, 0)
+  wid_class->draw = on_draw;
+#else
   wid_class->expose_event = on_expose;
+#endif
 
   g_type_class_add_private (obj_class, sizeof (TaskTitlePrivate));
 }
@@ -411,7 +479,7 @@ task_title_init (TaskTitle *title)
     	
   priv = title->priv = TASK_TITLE_GET_PRIVATE (title);
 
-  priv->screen = matewnck_screen_get_default ();
+  priv->screen = wnck_screen_get_default ();
   priv->window = NULL;
 
   /* FIXME we can add an option for this in future */
@@ -460,11 +528,16 @@ task_title_init (TaskTitle *title)
                     G_CALLBACK (on_enter_notify), title);
   g_signal_connect (priv->button, "leave-notify-event",
                     G_CALLBACK (on_leave_notify), title);
+#if GTK_CHECK_VERSION (3, 0, 0)
+  g_signal_connect (priv->button, "draw",
+                    G_CALLBACK (on_button_draw), title);
+#else
   g_signal_connect (priv->button, "expose-event",
                     G_CALLBACK (on_button_expose), title);
+#endif
 
   /* Load the quit icon.  We have to do this in such a god-forsaken way
-     because of http://bugzilla.mate.org/show_bug.cgi?id=581359 and the
+     because of http://bugzilla.gnome.org/show_bug.cgi?id=581359 and the
      fact that we support as far back as GTK+ 2.12 (which never passes
      FORCE_SIZE in GtkImage).  The only way to guarantee icon size is to
      load and scale it ourselves.  We don't do this for all the other icons
